#
# AWS v4 auto credential configuration (v1.2)
#
#  https://docs.aws.amazon.com/cli/latest/userguide/cli-configure-files.html
#  https://docs.aws.amazon.com/cli/latest/userguide/cli-configure-envvars.html
#
# HOWTO SETUP
#
# 1) Setup your profile:
#
#   aws configure
#
# 2) Test
#
#   aws ...
#
# 3) Add varnish to your user group:
#
#   sudo usermod -a -G $(id -gn) varnish
#   groups varnish
#   chmod g+r ~/.aws/*
#
# 4a) Add AWS_HOME to the varnish systemd unit file override:
#
#   printf [Service]\\nEnvironment=AWS_HOME=$HOME\\n |\
#     sudo tee -a /etc/systemd/system/varnish.service.d/override.conf
#
# 4b) OR symlink .aws to /etc/varnish:
#
#   echo "$HOME/.aws /etc/varnish" | sudo xargs ln -s
#
# ---
#

include "aws/init.vcl";

import std;

sub vcl_init
{
	# From init
	#new aws_credentials = kvstore.init();
	#new aws_config = kvstore.init();

	aws_credentials.init();
	aws_config.init();

	# aws_credentials
	if (std.getenv("AWS_SHARED_CREDENTIALS_FILE")) {
		aws_credentials.init_conf(std.getenv("AWS_SHARED_CREDENTIALS_FILE"));
	} else if (aws_credentials.init_conf(std.getenv("AWS_HOME") + "/.aws/credentials") < 1) {
		aws_credentials.init_conf("/etc/varnish/.aws/credentials");
	}

	# aws_config
	if (std.getenv("AWS_CONFIG_FILE")) {
		aws_config.init_conf(std.getenv("AWS_CONFIG_FILE"));
	} else if (aws_config.init_conf(std.getenv("AWS_HOME") + "/.aws/config") < 1) {
		aws_config.init_conf("/etc/varnish/.aws/config");
	}

	# Default aws_access_key_id
	if (std.getenv("AWS_ACCESS_KEY_ID")) {
		aws_credentials.set("default_aws_access_key_id", std.getenv("AWS_ACCESS_KEY_ID"));
	}

	# Default aws_secret_access_key
	if (std.getenv("AWS_SECRET_ACCESS_KEY")) {
		aws_credentials.set("default_aws_secret_access_key", std.getenv("AWS_SECRET_ACCESS_KEY"));
	}

	# Default region
	if (std.getenv("AWS_DEFAULT_REGION")) {
		aws_config.set("default_region", std.getenv("AWS_DEFAULT_REGION"));
	}

	# Default profile
	if (std.getenv("AWS_PROFILE")) {
		aws_config.set("profile", std.getenv("AWS_PROFILE"));
	}

	# Default algorithm
	if (std.getenv("AWS_DEFAULT_ALGORITHM")) {
		aws_config.set("default_algorithm", std.getenv("AWS_DEFAULT_ALGORITHM"));
	}

	std.log("AWS auto init: " + (aws_credentials.size() + aws_config.size()) + " records");
}

# EOF
